@@ -2,24 +2,24 @@
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Namespaces {
     /// namespaces
-    #[prost(string, repeated, tag = "1")]
+    #[prost(string, repeated, tag="1")]
     pub namespaces: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// NamespacedName
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct NamespacedName {
     /// the namespace of the resource in Kubernetes
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub namespace: ::prost::alloc::string::String,
     /// the name of the resource in Kubernetes
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub name: ::prost::alloc::string::String,
 }
 /// NamespacedNames
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct NamespacedNames {
     /// a list of namespaced names in Kubernetes
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub namespaced_names: ::prost::alloc::vec::Vec<NamespacedName>,
 }
 /// Encryption key.
@@ -28,7 +28,7 @@ pub struct NamespacedNames {
 pub struct EncryptionKey {
     /// Google KMS encryption key in the format:
     /// projects/<project>/locations/<location>/keyRings/<key-ring>/cryptoKeys/<key>
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub gcp_kms_encryption_key: ::prost::alloc::string::String,
 }
 /// Restore as stored in Platform log. It's used to log the update details of a
@@ -38,22 +38,19 @@ pub struct EncryptionKey {
 pub struct LoggedRestore {
     /// Full name of the Backup resource this Restore resource used to restore
     /// from. Format: projects/*/locations/*/backupPlans/*/backups/*.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub backup: ::prost::alloc::string::String,
     /// GCP Labels.
-    #[prost(btree_map = "string, string", tag = "2")]
-    pub labels: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        ::prost::alloc::string::String,
-    >,
+    #[prost(btree_map="string, string", tag="2")]
+    pub labels: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
     /// User specified descriptive string for this Restore.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub description: ::prost::alloc::string::String,
     /// The current state of the Restore.
-    #[prost(enumeration = "logged_restore::State", tag = "4")]
+    #[prost(enumeration="logged_restore::State", tag="4")]
     pub state: i32,
     /// Human-readable description of why the Restore is in its current state.
-    #[prost(string, tag = "5")]
+    #[prost(string, tag="5")]
     pub state_reason: ::prost::alloc::string::String,
 }
 /// Nested message and enum types in `LoggedRestore`.
@@ -85,28 +82,25 @@ pub mod logged_restore {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct LoggedBackupPlan {
     /// User specified descriptive string for this BackupPlan.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub description: ::prost::alloc::string::String,
     /// GCP resource name of the source cluster for this BackupPlan.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub cluster: ::prost::alloc::string::String,
     /// RetentionPolicy governs lifecycle of Backups created under this plan.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub retention_policy: ::core::option::Option<logged_backup_plan::RetentionPolicy>,
     /// A set of custom labels supplied by user.
-    #[prost(btree_map = "string, string", tag = "4")]
-    pub labels: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        ::prost::alloc::string::String,
-    >,
+    #[prost(btree_map="string, string", tag="4")]
+    pub labels: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
     /// Defines scheduled Backup creation under this BackupPlan.
-    #[prost(message, optional, tag = "5")]
+    #[prost(message, optional, tag="5")]
     pub backup_schedule: ::core::option::Option<logged_backup_plan::Schedule>,
     /// A flag indicates whether the plan has been deactivated.
-    #[prost(bool, tag = "6")]
+    #[prost(bool, tag="6")]
     pub deactivated: bool,
     /// Defines backup configuration of this BackupPlan.
-    #[prost(message, optional, tag = "7")]
+    #[prost(message, optional, tag="7")]
     pub backup_config: ::core::option::Option<logged_backup_plan::BackupConfig>,
 }
 /// Nested message and enum types in `LoggedBackupPlan`.
@@ -119,29 +113,29 @@ pub mod logged_backup_plan {
     pub struct RetentionPolicy {
         /// Number of days during which deletion of a Backup created under this
         /// BackupPlan will be blocked.
-        #[prost(int32, tag = "1")]
+        #[prost(int32, tag="1")]
         pub backup_delete_lock_days: i32,
         /// Number of days after which the service will delete a Backup.
         /// If specified, a Backup created under this BackupPlan will be
         /// automatically deleted after its age reaches create_time +
         /// backup_retain_days.
-        #[prost(int32, tag = "2")]
+        #[prost(int32, tag="2")]
         pub backup_retain_days: i32,
         /// A flag denotes that the retention policy of this BackupPlan is locked.
         /// If set to True, no further update is allowed on this policy, including
         /// the 'locked' field itself.
         /// Default to False.
-        #[prost(bool, tag = "3")]
+        #[prost(bool, tag="3")]
         pub locked: bool,
     }
     /// Schedule, an inner message type defines a cron schedule.
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Schedule {
         /// A cron style string schedule on which an operation will be executed.
-        #[prost(string, tag = "1")]
+        #[prost(string, tag="1")]
         pub cron_schedule: ::prost::alloc::string::String,
         /// A flag to toggle scheduled operation.
-        #[prost(bool, tag = "2")]
+        #[prost(bool, tag="2")]
         pub paused: bool,
     }
     /// BackupConfig, an inner message type defines the configuration of creating
@@ -149,16 +143,16 @@ pub mod logged_backup_plan {
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct BackupConfig {
         /// A boolean flag specifies whether volume data should be backed up
-        #[prost(bool, tag = "4")]
+        #[prost(bool, tag="4")]
         pub include_volume_data: bool,
         /// A boolean flag specifies whether secrets should be backed up
-        #[prost(bool, tag = "5")]
+        #[prost(bool, tag="5")]
         pub include_secrets: bool,
         /// Custom encryption key. For preview, support GCP KMS only.
         /// This only contains the key metadata, and no key material.
-        #[prost(message, optional, tag = "6")]
+        #[prost(message, optional, tag="6")]
         pub encryption_key: ::core::option::Option<super::EncryptionKey>,
-        #[prost(oneof = "backup_config::BackupScope", tags = "1, 2, 3")]
+        #[prost(oneof="backup_config::BackupScope", tags="1, 2, 3")]
         pub backup_scope: ::core::option::Option<backup_config::BackupScope>,
     }
     /// Nested message and enum types in `BackupConfig`.
@@ -166,13 +160,13 @@ pub mod logged_backup_plan {
         #[derive(Clone, PartialEq, ::prost::Oneof)]
         pub enum BackupScope {
             /// If set to true, backup whole cluster
-            #[prost(bool, tag = "1")]
+            #[prost(bool, tag="1")]
             AllNamespaces(bool),
             /// If set, backup the list of namespaces
-            #[prost(message, tag = "2")]
+            #[prost(message, tag="2")]
             SelectedNamespaces(super::super::Namespaces),
             /// If set, backup the list of applications
-            #[prost(message, tag = "3")]
+            #[prost(message, tag="3")]
             SelectedApplications(super::super::NamespacedNames),
         }
     }
@@ -183,27 +177,24 @@ pub mod logged_backup_plan {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct LoggedBackup {
     /// A set of custom labels supplied by user.
-    #[prost(btree_map = "string, string", tag = "1")]
-    pub labels: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        ::prost::alloc::string::String,
-    >,
+    #[prost(btree_map="string, string", tag="1")]
+    pub labels: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
     /// delete_lock_days specifies the number of days from the create_time of this
     /// Backup before which deletion will be blocked.
-    #[prost(int32, tag = "2")]
+    #[prost(int32, tag="2")]
     pub delete_lock_days: i32,
     /// retain_days specifies the desired number of days from the create_time of
     /// this Backup after which it will be automatically deleted.
-    #[prost(int32, tag = "3")]
+    #[prost(int32, tag="3")]
     pub retain_days: i32,
     /// User specified descriptive string for this Backup.
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub description: ::prost::alloc::string::String,
     /// Current state of the Backup
-    #[prost(enumeration = "logged_backup::State", tag = "5")]
+    #[prost(enumeration="logged_backup::State", tag="5")]
     pub state: i32,
     /// Human-readable description of why the backup is in the current `state`.
-    #[prost(string, tag = "6")]
+    #[prost(string, tag="6")]
     pub state_reason: ::prost::alloc::string::String,
 }
 /// Nested message and enum types in `LoggedBackup`.
@@ -235,12 +226,12 @@ pub mod logged_backup {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct LoggedRestorePlan {
     /// User specified descriptive string for this RestorePlan.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub description: ::prost::alloc::string::String,
     /// The BackupPlan from which Backups may be used as the source
     /// for Restores created via this RestorePlan.
     /// Format: projects/*/locations/*/backupPlans/*.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub backup_plan: ::prost::alloc::string::String,
     /// The target cluster into which Restores created via this RestorePlan
     /// will restore data. NOTE: the cluster's region must be the same as the
@@ -248,17 +239,14 @@ pub struct LoggedRestorePlan {
     /// Possible formats:
     ///   1. projects/*/locations/*/clusters/*
     ///   2. projects/*/zones/*/clusters/*
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub cluster: ::prost::alloc::string::String,
     /// Configuration of Restores created via this RestorePlan.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub restore_config: ::core::option::Option<RestoreConfig>,
     /// A set of custom labels supplied by user.
-    #[prost(btree_map = "string, string", tag = "5")]
-    pub labels: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        ::prost::alloc::string::String,
-    >,
+    #[prost(btree_map="string, string", tag="5")]
+    pub labels: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
 }
 /// Configuration of a restore.
 #[derive(Clone, PartialEq, ::prost::Message)]
@@ -266,48 +254,37 @@ pub struct RestoreConfig {
     /// Specifies the mechanism to be used to restore volume data.
     /// Default: VOLUME_DATA_RESTORE_POLICY_UNSPECIFIED (will be treated as
     /// NO_VOLUME_DATA_RESTORATION).
-    #[prost(enumeration = "restore_config::VolumeDataRestorePolicy", tag = "1")]
+    #[prost(enumeration="restore_config::VolumeDataRestorePolicy", tag="1")]
     pub volume_data_restore_policy: i32,
     /// Defines the behavior for handling the situation where cluster-scoped
     /// resources being restored already exist in the target cluster. This MUST be
     /// set to a value other than CLUSTER_RESOURCE_CONFLICT_POLICY_UNSPECIFIED if
     /// cluster_resource_restore_scope is not empty.
-    #[prost(
-        enumeration = "restore_config::ClusterResourceConflictPolicy",
-        tag = "2"
-    )]
+    #[prost(enumeration="restore_config::ClusterResourceConflictPolicy", tag="2")]
     pub cluster_resource_conflict_policy: i32,
     /// Defines the behavior for handling the situation where sets of namespaced
     /// resources being restored already exist in the target cluster. This MUST be
     /// set to a value other than NAMESPACED_RESOURCE_RESTORE_MODE_UNSPECIFIED if
     /// any namespaced restoration is configured via
     /// namespaced_resource_restore_scope .
-    #[prost(
-        enumeration = "restore_config::NamespacedResourceRestoreMode",
-        tag = "3"
-    )]
+    #[prost(enumeration="restore_config::NamespacedResourceRestoreMode", tag="3")]
     pub namespaced_resource_restore_mode: i32,
     /// Identifies the cluster-scoped resources to restore from the Backup.
     /// Not specifying it means NO cluster resource will be restored.
-    #[prost(message, optional, tag = "4")]
-    pub cluster_resource_restore_scope:
-        ::core::option::Option<restore_config::ClusterResourceRestoreScope>,
+    #[prost(message, optional, tag="4")]
+    pub cluster_resource_restore_scope: ::core::option::Option<restore_config::ClusterResourceRestoreScope>,
     /// A list of transformation rules to be applied against Kubernetes resources
     /// as they are selected for restoration from a Backup. Rules are executed in
     /// order defined - this order matters, as changes made by a rule may impact
     /// the filtering logic of subsequent rules. An empty list means no
     /// substitution will occur.
-    #[prost(message, repeated, tag = "8")]
+    #[prost(message, repeated, tag="8")]
     pub substitution_rules: ::prost::alloc::vec::Vec<restore_config::SubstitutionRule>,
     /// Specifies the namespaced resources to restore from the Backup.
     /// Only one of the entries may be specified. If not specified, NO namespaced
     /// resources will be restored.
-    #[prost(
-        oneof = "restore_config::NamespacedResourceRestoreScope",
-        tags = "5, 6, 7"
-    )]
-    pub namespaced_resource_restore_scope:
-        ::core::option::Option<restore_config::NamespacedResourceRestoreScope>,
+    #[prost(oneof="restore_config::NamespacedResourceRestoreScope", tags="5, 6, 7")]
+    pub namespaced_resource_restore_scope: ::core::option::Option<restore_config::NamespacedResourceRestoreScope>,
 }
 /// Nested message and enum types in `RestoreConfig`.
 pub mod restore_config {
@@ -319,11 +296,11 @@ pub mod restore_config {
         /// API group string of a Kubernetes resource, e.g.
         /// "apiextensions.k8s.io", "storage.k8s.io", etc.
         /// Note: use empty string for core API group
-        #[prost(string, tag = "1")]
+        #[prost(string, tag="1")]
         pub resource_group: ::prost::alloc::string::String,
         /// Kind of a Kubernetes resource, e.g.
         /// "CustomResourceDefinition", "StorageClass", etc.
-        #[prost(string, tag = "2")]
+        #[prost(string, tag="2")]
         pub resource_kind: ::prost::alloc::string::String,
     }
     /// Identifies the cluster-scoped resources to restore from the Backup.
@@ -333,7 +310,7 @@ pub mod restore_config {
         /// Backup.  An empty list means that NO cluster-scoped resources will be
         /// restored. Note that Namespaces and PersistentVolume restoration is
         /// handled separately and is not governed by this field.
-        #[prost(message, repeated, tag = "1")]
+        #[prost(message, repeated, tag="1")]
         pub selected_group_kinds: ::prost::alloc::vec::Vec<GroupKind>,
     }
     /// A transformation rule to be applied against Kubernetes resources as they
@@ -348,14 +325,14 @@ pub mod restore_config {
         /// will be candidates for substitution).
         /// To mix cluster-scoped and namespaced resources in the same rule, use an
         /// empty string ("") as one of the target namespaces.
-        #[prost(string, repeated, tag = "1")]
+        #[prost(string, repeated, tag="1")]
         pub target_namespaces: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
         /// (Filtering parameter) Any resource subject to substitution must belong to
         /// one of the listed "types".
         /// If this field is not provided, no type filtering will be performed (all
         /// resources of all types matching previous filtering parameters will be
         /// candidates for substitution).
-        #[prost(message, repeated, tag = "2")]
+        #[prost(message, repeated, tag="2")]
         pub target_group_kinds: ::prost::alloc::vec::Vec<GroupKind>,
         /// This is a \[JSONPath\]
         /// ([<https://kubernetes.io/docs/reference/kubectl/jsonpath/>)
@@ -364,7 +341,7 @@ pub mod restore_config {
         /// are not matched with this expression will not be candidates for
         /// substitution) as well as a field identifier (identifies exactly which
         /// fields out of the candidate resources will be modified).
-        #[prost(string, tag = "3")]
+        #[prost(string, tag="3")]
         pub target_json_path: ::prost::alloc::string::String,
         /// (Filtering parameter) This is a [regular expression]
         /// (<https://en.wikipedia.org/wiki/Regular_expression>)
@@ -375,12 +352,12 @@ pub mod restore_config {
         /// then ALL fields matched by the target_json_path expression will undergo
         /// substitution. Note that an empty (e.g., "", rather than unspecified)
         /// value for for this field will only match empty fields.
-        #[prost(string, tag = "4")]
+        #[prost(string, tag="4")]
         pub original_value_pattern: ::prost::alloc::string::String,
         /// This is the new value to set for any fields that pass the filtering and
         /// selection criteria. To remove a value from a Kubernetes resource, either
         /// leave this field unspecified, or set it to the empty string ("").
-        #[prost(string, tag = "5")]
+        #[prost(string, tag="5")]
         pub new_value: ::prost::alloc::string::String,
     }
     /// Defines how volume data should be restored
@@ -447,16 +424,16 @@ pub mod restore_config {
     pub enum NamespacedResourceRestoreScope {
         /// Restore all namespaced resources in the Backup if set to "True".
         /// Specifying this field to "False" is an error.
-        #[prost(bool, tag = "5")]
+        #[prost(bool, tag="5")]
         AllNamespaces(bool),
         /// A list of selected Namespaces to restore from the Backup. The listed
         /// Namespaces and all resources contained in them will be restored.
-        #[prost(message, tag = "6")]
+        #[prost(message, tag="6")]
         SelectedNamespaces(super::Namespaces),
         /// A list of selected ProtectedApplications to restore. The listed
         /// ProtectedApplications and all the resources to which they refer will be
         /// restored.
-        #[prost(message, tag = "7")]
+        #[prost(message, tag="7")]
         SelectedApplications(super::NamespacedNames),
     }
 }
@@ -468,20 +445,20 @@ pub struct BackupPlanChange {
     /// The full name of the old BackupPlan resource that is being modified.
     /// Empty for creation.
     /// Format: projects/{project}/locations/{location}/backupPlans/{backup_plan}
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub backup_plan: ::prost::alloc::string::String,
     /// Type of the change is being made.
-    #[prost(enumeration = "ChangeType", tag = "2")]
+    #[prost(enumeration="ChangeType", tag="2")]
     pub change_type: i32,
     /// Modification details.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub update_mask: ::core::option::Option<::prost_types::FieldMask>,
     /// The input BackupPlan resource with the updated fields populated to update
     /// the source BackupPlan to.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub input_backup_plan: ::core::option::Option<LoggedBackupPlan>,
     /// The error code and message.
-    #[prost(message, optional, tag = "5")]
+    #[prost(message, optional, tag="5")]
     pub error: ::core::option::Option<super::super::super::super::rpc::Status>,
 }
 /// use case 2
@@ -492,24 +469,24 @@ pub struct BackupChange {
     /// The full name of the Backup resource that is being modified.
     /// Format:
     /// projects/{project}/locations/{location}/backupPlans/{backup_plan}/backups/{backup}
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub backup: ::prost::alloc::string::String,
     /// Type of the change is being made.
-    #[prost(enumeration = "ChangeType", tag = "2")]
+    #[prost(enumeration="ChangeType", tag="2")]
     pub change_type: i32,
     /// Whether the change is made manually or automatically.
-    #[prost(bool, tag = "3")]
+    #[prost(bool, tag="3")]
     pub scheduled: bool,
     /// Modification details.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub update_mask: ::core::option::Option<::prost_types::FieldMask>,
     /// The input Backup resource with the updated fields populated to update
     /// the source Backup to, or the backup created automatically from retention
     /// policy.
-    #[prost(message, optional, tag = "5")]
+    #[prost(message, optional, tag="5")]
     pub input_backup: ::core::option::Option<LoggedBackup>,
     /// The error code and message.
-    #[prost(message, optional, tag = "6")]
+    #[prost(message, optional, tag="6")]
     pub error: ::core::option::Option<super::super::super::super::rpc::Status>,
 }
 /// use case 3
@@ -520,20 +497,20 @@ pub struct RestorePlanChange {
     /// The full name of the RestorePlan resource that is being modified.
     /// Empty for creation.
     /// Format: projects/*/locations/*/restorePlans/*
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub restore_plan: ::prost::alloc::string::String,
     /// Type of the change is being made.
-    #[prost(enumeration = "ChangeType", tag = "2")]
+    #[prost(enumeration="ChangeType", tag="2")]
     pub change_type: i32,
     /// Modification details.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub update_mask: ::core::option::Option<::prost_types::FieldMask>,
     /// The input RestorePlan resource with the updated fields populated to update
     /// the source RestorePlan to.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub input_restore_plan: ::core::option::Option<LoggedRestorePlan>,
     /// The error code and message.
-    #[prost(message, optional, tag = "5")]
+    #[prost(message, optional, tag="5")]
     pub error: ::core::option::Option<super::super::super::super::rpc::Status>,
 }
 /// use case 4
@@ -544,20 +521,20 @@ pub struct RestoreChange {
     /// The full name of the Restore resource that is being modified.
     /// Empty for creation.
     /// Format: projects/*/locations/*/restorePlans/*/restores/*
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub restore: ::prost::alloc::string::String,
     /// Type of the change is being made.
-    #[prost(enumeration = "ChangeType", tag = "2")]
+    #[prost(enumeration="ChangeType", tag="2")]
     pub change_type: i32,
     /// Modification details.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub update_mask: ::core::option::Option<::prost_types::FieldMask>,
     /// The input Restore resource with the updated fields populated to update
     /// the source Restore to.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub input_restore: ::core::option::Option<LoggedRestore>,
     /// The error code and message.
-    #[prost(message, optional, tag = "5")]
+    #[prost(message, optional, tag="5")]
     pub error: ::core::option::Option<super::super::super::super::rpc::Status>,
 }
 /// The type of changes this log is about.
