@@ -5,10 +5,10 @@ pub struct IndexField {
     /// by \[google.firestore.v1beta1.Document.fields][fields\].
     /// Special field path `__name__` may be used by itself or at the end of a
     /// path. `__type__` may be used only at the end of path.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub field_path: ::prost::alloc::string::String,
     /// The field's mode.
-    #[prost(enumeration = "index_field::Mode", tag = "2")]
+    #[prost(enumeration="index_field::Mode", tag="2")]
     pub mode: i32,
 }
 /// Nested message and enum types in `IndexField`.
@@ -35,17 +35,17 @@ pub mod index_field {
 pub struct Index {
     /// The resource name of the index.
     /// Output only.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// The collection ID to which this index applies. Required.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub collection_id: ::prost::alloc::string::String,
     /// The fields to index.
-    #[prost(message, repeated, tag = "3")]
+    #[prost(message, repeated, tag="3")]
     pub fields: ::prost::alloc::vec::Vec<IndexField>,
     /// The state of the index.
     /// Output only.
-    #[prost(enumeration = "index::State", tag = "6")]
+    #[prost(enumeration="index::State", tag="6")]
     pub state: i32,
 }
 /// Nested message and enum types in `Index`.
@@ -81,26 +81,26 @@ pub mod index {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct IndexOperationMetadata {
     /// The time that work began on the operation.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub start_time: ::core::option::Option<::prost_types::Timestamp>,
     /// The time the operation ended, either successfully or otherwise. Unset if
     /// the operation is still active.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub end_time: ::core::option::Option<::prost_types::Timestamp>,
     /// The index resource that this operation is acting on. For example:
     /// `projects/{project_id}/databases/{database_id}/indexes/{index_id}`
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub index: ::prost::alloc::string::String,
     /// The type of index operation.
-    #[prost(enumeration = "index_operation_metadata::OperationType", tag = "4")]
+    #[prost(enumeration="index_operation_metadata::OperationType", tag="4")]
     pub operation_type: i32,
     /// True if the \[google.longrunning.Operation\] was cancelled. If the
     /// cancellation is in progress, cancelled will be true but
     /// \[google.longrunning.Operation.done][google.longrunning.Operation.done\] will be false.
-    #[prost(bool, tag = "5")]
+    #[prost(bool, tag="5")]
     pub cancelled: bool,
     /// Progress of the existing operation, measured in number of documents.
-    #[prost(message, optional, tag = "6")]
+    #[prost(message, optional, tag="6")]
     pub document_progress: ::core::option::Option<Progress>,
 }
 /// Nested message and enum types in `IndexOperationMetadata`.
@@ -120,11 +120,11 @@ pub mod index_operation_metadata {
 pub struct Progress {
     /// An estimate of how much work has been completed. Note that this may be
     /// greater than `work_estimated`.
-    #[prost(int64, tag = "1")]
+    #[prost(int64, tag="1")]
     pub work_completed: i64,
     /// An estimate of how much work needs to be performed. Zero if the
     /// work estimate is unavailable. May change as work progresses.
-    #[prost(int64, tag = "2")]
+    #[prost(int64, tag="2")]
     pub work_estimated: i64,
 }
 /// The request for \[FirestoreAdmin.CreateIndex][google.firestore.admin.v1beta1.FirestoreAdmin.CreateIndex\].
@@ -132,11 +132,11 @@ pub struct Progress {
 pub struct CreateIndexRequest {
     /// The name of the database this index will apply to. For example:
     /// `projects/{project_id}/databases/{database_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub parent: ::prost::alloc::string::String,
     /// The index to create. The name and state fields are output only and will be
     /// ignored. Certain single field indexes cannot be created or deleted.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub index: ::core::option::Option<Index>,
 }
 /// The request for \[FirestoreAdmin.GetIndex][google.firestore.admin.v1beta1.FirestoreAdmin.GetIndex\].
@@ -144,7 +144,7 @@ pub struct CreateIndexRequest {
 pub struct GetIndexRequest {
     /// The name of the index. For example:
     /// `projects/{project_id}/databases/{database_id}/indexes/{index_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
 }
 /// The request for \[FirestoreAdmin.ListIndexes][google.firestore.admin.v1beta1.FirestoreAdmin.ListIndexes\].
@@ -152,15 +152,15 @@ pub struct GetIndexRequest {
 pub struct ListIndexesRequest {
     /// The database name. For example:
     /// `projects/{project_id}/databases/{database_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub parent: ::prost::alloc::string::String,
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub filter: ::prost::alloc::string::String,
     /// The standard List page size.
-    #[prost(int32, tag = "3")]
+    #[prost(int32, tag="3")]
     pub page_size: i32,
     /// The standard List page token.
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub page_token: ::prost::alloc::string::String,
 }
 /// The request for \[FirestoreAdmin.DeleteIndex][google.firestore.admin.v1beta1.FirestoreAdmin.DeleteIndex\].
@@ -168,17 +168,17 @@ pub struct ListIndexesRequest {
 pub struct DeleteIndexRequest {
     /// The index name. For example:
     /// `projects/{project_id}/databases/{database_id}/indexes/{index_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
 }
 /// The response for \[FirestoreAdmin.ListIndexes][google.firestore.admin.v1beta1.FirestoreAdmin.ListIndexes\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListIndexesResponse {
     /// The indexes.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub indexes: ::prost::alloc::vec::Vec<Index>,
     /// The standard List next-page token.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub next_page_token: ::prost::alloc::string::String,
 }
 /// The request for \[FirestoreAdmin.ExportDocuments][google.firestore.admin.v1beta1.FirestoreAdmin.ExportDocuments\].
@@ -186,10 +186,10 @@ pub struct ListIndexesResponse {
 pub struct ExportDocumentsRequest {
     /// Database to export. Should be of the form:
     /// `projects/{project_id}/databases/{database_id}`.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// Which collection ids to export. Unspecified means all collections.
-    #[prost(string, repeated, tag = "3")]
+    #[prost(string, repeated, tag="3")]
     pub collection_ids: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
     /// The output URI. Currently only supports Google Cloud Storage URIs of the
     /// form: `gs://BUCKET_NAME\[/NAMESPACE_PATH\]`, where `BUCKET_NAME` is the name
@@ -199,7 +199,7 @@ pub struct ExportDocumentsRequest {
     /// guidelines: <https://cloud.google.com/storage/docs/naming.>
     /// If the URI is a bucket (without a namespace path), a prefix will be
     /// generated based on the start time.
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub output_uri_prefix: ::prost::alloc::string::String,
 }
 /// The request for \[FirestoreAdmin.ImportDocuments][google.firestore.admin.v1beta1.FirestoreAdmin.ImportDocuments\].
@@ -207,18 +207,18 @@ pub struct ExportDocumentsRequest {
 pub struct ImportDocumentsRequest {
     /// Database to import into. Should be of the form:
     /// `projects/{project_id}/databases/{database_id}`.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// Which collection ids to import. Unspecified means all collections included
     /// in the import.
-    #[prost(string, repeated, tag = "3")]
+    #[prost(string, repeated, tag="3")]
     pub collection_ids: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
     /// Location of the exported files.
     /// This must match the output_uri_prefix of an ExportDocumentsResponse from
     /// an export that has completed successfully.
     /// See:
     /// \[google.firestore.admin.v1beta1.ExportDocumentsResponse.output_uri_prefix][google.firestore.admin.v1beta1.ExportDocumentsResponse.output_uri_prefix\].
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub input_uri_prefix: ::prost::alloc::string::String,
 }
 /// Returned in the \[google.longrunning.Operation][google.longrunning.Operation\] response field.
@@ -227,59 +227,59 @@ pub struct ExportDocumentsResponse {
     /// Location of the output files. This can be used to begin an import
     /// into Cloud Firestore (this project or another project) after the operation
     /// completes successfully.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub output_uri_prefix: ::prost::alloc::string::String,
 }
 /// Metadata for ExportDocuments operations.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ExportDocumentsMetadata {
     /// The time that work began on the operation.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub start_time: ::core::option::Option<::prost_types::Timestamp>,
     /// The time the operation ended, either successfully or otherwise. Unset if
     /// the operation is still active.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub end_time: ::core::option::Option<::prost_types::Timestamp>,
     /// The state of the export operation.
-    #[prost(enumeration = "OperationState", tag = "3")]
+    #[prost(enumeration="OperationState", tag="3")]
     pub operation_state: i32,
     /// An estimate of the number of documents processed.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub progress_documents: ::core::option::Option<Progress>,
     /// An estimate of the number of bytes processed.
-    #[prost(message, optional, tag = "5")]
+    #[prost(message, optional, tag="5")]
     pub progress_bytes: ::core::option::Option<Progress>,
     /// Which collection ids are being exported.
-    #[prost(string, repeated, tag = "6")]
+    #[prost(string, repeated, tag="6")]
     pub collection_ids: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
     /// Where the entities are being exported to.
-    #[prost(string, tag = "7")]
+    #[prost(string, tag="7")]
     pub output_uri_prefix: ::prost::alloc::string::String,
 }
 /// Metadata for ImportDocuments operations.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ImportDocumentsMetadata {
     /// The time that work began on the operation.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub start_time: ::core::option::Option<::prost_types::Timestamp>,
     /// The time the operation ended, either successfully or otherwise. Unset if
     /// the operation is still active.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub end_time: ::core::option::Option<::prost_types::Timestamp>,
     /// The state of the import operation.
-    #[prost(enumeration = "OperationState", tag = "3")]
+    #[prost(enumeration="OperationState", tag="3")]
     pub operation_state: i32,
     /// An estimate of the number of documents processed.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub progress_documents: ::core::option::Option<Progress>,
     /// An estimate of the number of bytes processed.
-    #[prost(message, optional, tag = "5")]
+    #[prost(message, optional, tag="5")]
     pub progress_bytes: ::core::option::Option<Progress>,
     /// Which collection ids are being imported.
-    #[prost(string, repeated, tag = "6")]
+    #[prost(string, repeated, tag="6")]
     pub collection_ids: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
     /// The location of the documents being imported.
-    #[prost(string, tag = "7")]
+    #[prost(string, tag="7")]
     pub input_uri_prefix: ::prost::alloc::string::String,
 }
 /// The various possible states for an ongoing Operation.
@@ -305,53 +305,53 @@ pub enum OperationState {
     /// google.longrunning.Operations.CancelOperation.
     Cancelled = 7,
 }
-#[doc = r" Generated client implementations."]
+/// Generated client implementations.
 pub mod firestore_admin_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " The Cloud Firestore Admin API."]
-    #[doc = ""]
-    #[doc = " This API provides several administrative services for Cloud Firestore."]
-    #[doc = ""]
-    #[doc = " # Concepts"]
-    #[doc = ""]
-    #[doc = " Project, Database, Namespace, Collection, and Document are used as defined in"]
-    #[doc = " the Google Cloud Firestore API."]
-    #[doc = ""]
-    #[doc = " Operation: An Operation represents work being performed in the background."]
-    #[doc = ""]
-    #[doc = ""]
-    #[doc = " # Services"]
-    #[doc = ""]
-    #[doc = " ## Index"]
-    #[doc = ""]
-    #[doc = " The index service manages Cloud Firestore indexes."]
-    #[doc = ""]
-    #[doc = " Index creation is performed asynchronously."]
-    #[doc = " An Operation resource is created for each such asynchronous operation."]
-    #[doc = " The state of the operation (including any errors encountered)"]
-    #[doc = " may be queried via the Operation resource."]
-    #[doc = ""]
-    #[doc = " ## Metadata"]
-    #[doc = ""]
-    #[doc = " Provides metadata and statistical information about data in Cloud Firestore."]
-    #[doc = " The data provided as part of this API may be stale."]
-    #[doc = ""]
-    #[doc = " ## Operation"]
-    #[doc = ""]
-    #[doc = " The Operations collection provides a record of actions performed for the"]
-    #[doc = " specified Project (including any Operations in progress). Operations are not"]
-    #[doc = " created directly but through calls on other collections or resources."]
-    #[doc = ""]
-    #[doc = " An Operation that is not yet done may be cancelled. The request to cancel is"]
-    #[doc = " asynchronous and the Operation may continue to run for some time after the"]
-    #[doc = " request to cancel is made."]
-    #[doc = ""]
-    #[doc = " An Operation that is done may be deleted so that it is no longer listed as"]
-    #[doc = " part of the Operation collection."]
-    #[doc = ""]
-    #[doc = " Operations are created by service `FirestoreAdmin`, but are accessed via"]
-    #[doc = " service `google.longrunning.Operations`."]
+    /// The Cloud Firestore Admin API.
+    ///
+    /// This API provides several administrative services for Cloud Firestore.
+    ///
+    /// # Concepts
+    ///
+    /// Project, Database, Namespace, Collection, and Document are used as defined in
+    /// the Google Cloud Firestore API.
+    ///
+    /// Operation: An Operation represents work being performed in the background.
+    ///
+    ///
+    /// # Services
+    ///
+    /// ## Index
+    ///
+    /// The index service manages Cloud Firestore indexes.
+    ///
+    /// Index creation is performed asynchronously.
+    /// An Operation resource is created for each such asynchronous operation.
+    /// The state of the operation (including any errors encountered)
+    /// may be queried via the Operation resource.
+    ///
+    /// ## Metadata
+    ///
+    /// Provides metadata and statistical information about data in Cloud Firestore.
+    /// The data provided as part of this API may be stale.
+    ///
+    /// ## Operation
+    ///
+    /// The Operations collection provides a record of actions performed for the
+    /// specified Project (including any Operations in progress). Operations are not
+    /// created directly but through calls on other collections or resources.
+    ///
+    /// An Operation that is not yet done may be cancelled. The request to cancel is
+    /// asynchronous and the Operation may continue to run for some time after the
+    /// request to cancel is made.
+    ///
+    /// An Operation that is done may be deleted so that it is no longer listed as
+    /// part of the Operation collection.
+    ///
+    /// Operations are created by service `FirestoreAdmin`, but are accessed via
+    /// service `google.longrunning.Operations`.
     #[derive(Debug, Clone)]
     pub struct FirestoreAdminClient<T> {
         inner: tonic::client::Grpc<T>,
@@ -359,8 +359,8 @@ pub mod firestore_admin_client {
     impl<T> FirestoreAdminClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -379,152 +379,173 @@ pub mod firestore_admin_client {
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             FirestoreAdminClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Creates the specified index."]
-        #[doc = " A newly created index's initial state is `CREATING`. On completion of the"]
-        #[doc = " returned [google.longrunning.Operation][google.longrunning.Operation], the state will be `READY`."]
-        #[doc = " If the index already exists, the call will return an `ALREADY_EXISTS`"]
-        #[doc = " status."]
-        #[doc = ""]
-        #[doc = " During creation, the process could result in an error, in which case the"]
-        #[doc = " index will move to the `ERROR` state. The process can be recovered by"]
-        #[doc = " fixing the data that caused the error, removing the index with"]
-        #[doc = " [delete][google.firestore.admin.v1beta1.FirestoreAdmin.DeleteIndex], then re-creating the index with"]
-        #[doc = " [create][google.firestore.admin.v1beta1.FirestoreAdmin.CreateIndex]."]
-        #[doc = ""]
-        #[doc = " Indexes with a single field cannot be created."]
+        /// Creates the specified index.
+        /// A newly created index's initial state is `CREATING`. On completion of the
+        /// returned [google.longrunning.Operation][google.longrunning.Operation], the state will be `READY`.
+        /// If the index already exists, the call will return an `ALREADY_EXISTS`
+        /// status.
+        ///
+        /// During creation, the process could result in an error, in which case the
+        /// index will move to the `ERROR` state. The process can be recovered by
+        /// fixing the data that caused the error, removing the index with
+        /// [delete][google.firestore.admin.v1beta1.FirestoreAdmin.DeleteIndex], then re-creating the index with
+        /// [create][google.firestore.admin.v1beta1.FirestoreAdmin.CreateIndex].
+        ///
+        /// Indexes with a single field cannot be created.
         pub async fn create_index(
             &mut self,
             request: impl tonic::IntoRequest<super::CreateIndexRequest>,
         ) -> Result<
-            tonic::Response<super::super::super::super::longrunning::Operation>,
-            tonic::Status,
-        > {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+                tonic::Response<super::super::super::super::longrunning::Operation>,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.firestore.admin.v1beta1.FirestoreAdmin/CreateIndex",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Lists the indexes that match the specified filters."]
+        /// Lists the indexes that match the specified filters.
         pub async fn list_indexes(
             &mut self,
             request: impl tonic::IntoRequest<super::ListIndexesRequest>,
         ) -> Result<tonic::Response<super::ListIndexesResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.firestore.admin.v1beta1.FirestoreAdmin/ListIndexes",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Gets an index."]
+        /// Gets an index.
         pub async fn get_index(
             &mut self,
             request: impl tonic::IntoRequest<super::GetIndexRequest>,
         ) -> Result<tonic::Response<super::Index>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.firestore.admin.v1beta1.FirestoreAdmin/GetIndex",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Deletes an index."]
+        /// Deletes an index.
         pub async fn delete_index(
             &mut self,
             request: impl tonic::IntoRequest<super::DeleteIndexRequest>,
         ) -> Result<tonic::Response<()>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.firestore.admin.v1beta1.FirestoreAdmin/DeleteIndex",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Exports a copy of all or a subset of documents from Google Cloud Firestore"]
-        #[doc = " to another storage system, such as Google Cloud Storage. Recent updates to"]
-        #[doc = " documents may not be reflected in the export. The export occurs in the"]
-        #[doc = " background and its progress can be monitored and managed via the"]
-        #[doc = " Operation resource that is created. The output of an export may only be"]
-        #[doc = " used once the associated operation is done. If an export operation is"]
-        #[doc = " cancelled before completion it may leave partial data behind in Google"]
-        #[doc = " Cloud Storage."]
+        /// Exports a copy of all or a subset of documents from Google Cloud Firestore
+        /// to another storage system, such as Google Cloud Storage. Recent updates to
+        /// documents may not be reflected in the export. The export occurs in the
+        /// background and its progress can be monitored and managed via the
+        /// Operation resource that is created. The output of an export may only be
+        /// used once the associated operation is done. If an export operation is
+        /// cancelled before completion it may leave partial data behind in Google
+        /// Cloud Storage.
         pub async fn export_documents(
             &mut self,
             request: impl tonic::IntoRequest<super::ExportDocumentsRequest>,
         ) -> Result<
-            tonic::Response<super::super::super::super::longrunning::Operation>,
-            tonic::Status,
-        > {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+                tonic::Response<super::super::super::super::longrunning::Operation>,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.firestore.admin.v1beta1.FirestoreAdmin/ExportDocuments",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Imports documents into Google Cloud Firestore. Existing documents with the"]
-        #[doc = " same name are overwritten. The import occurs in the background and its"]
-        #[doc = " progress can be monitored and managed via the Operation resource that is"]
-        #[doc = " created. If an ImportDocuments operation is cancelled, it is possible"]
-        #[doc = " that a subset of the data has already been imported to Cloud Firestore."]
+        /// Imports documents into Google Cloud Firestore. Existing documents with the
+        /// same name are overwritten. The import occurs in the background and its
+        /// progress can be monitored and managed via the Operation resource that is
+        /// created. If an ImportDocuments operation is cancelled, it is possible
+        /// that a subset of the data has already been imported to Cloud Firestore.
         pub async fn import_documents(
             &mut self,
             request: impl tonic::IntoRequest<super::ImportDocumentsRequest>,
         ) -> Result<
-            tonic::Response<super::super::super::super::longrunning::Operation>,
-            tonic::Status,
-        > {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+                tonic::Response<super::super::super::super::longrunning::Operation>,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.firestore.admin.v1beta1.FirestoreAdmin/ImportDocuments",
@@ -535,4 +556,5 @@ pub mod firestore_admin_client {
 }
 /// The metadata message for \[google.cloud.location.Location.metadata][google.cloud.location.Location.metadata\].
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct LocationMetadata {}
+pub struct LocationMetadata {
+}
